<?php

/**
 * Class 'XMLPageConnection' for the 'libconnect' extension.
 *
 * @author	Björn Heinermann <hein@zhaw.ch>
 * @package	TYPO3
 * @subpackage	tx_libconnect
 */

class XMLPageConnection {
    
   /**
    * Enable debug for logging errors to devLog
    *
    */
    private $debug = false;    
    
    private $extPiVars;
    private $proxy;
    private $proxyPort;
    
    public function __construct() {
	
		$this->setExtPiVars();
		$this->setExtConfVars();
		$this->setProxy();
		$this->setProxyPort();
    }
    
    /**
     * Läd die im typoscript gesetzten Variablen.
     */
    private function setExtPiVars() {
		$this->extPiVars = $GLOBALS['TSFE']->tmpl->setup['plugin.']['tx_libconnect.'];
    }
    
    /**
     * Lädt die in der Extension Konfiguration gesetzten Variablen.
     */
    private function setExtConfVars() {
		$ext_conf = unserialize($GLOBALS['TYPO3_CONF_VARS']['EXT']['extConf']['libconnect']);
        if ($ext_conf['debug'] == true) $this->debug = true;
        if ($ext_conf['debug'] == false) $this->debug = false;
    }

    /**
     * Setzt den Proxy Server 
     */
    private function setProxy() {
		$this->proxy = $this->extPiVars['proxy'];
    }
    
    /**
     * Setzt den Proxy Port 
     */
    private function setProxyPort() {
		$this->proxyPort = $this->extPiVars['proxy_port'];
    }
    
    /**
     * Holt XML Daten von einer Internetseite und gibt diese als array zurück
     *
     * @return SimpleXMLElement object
     */
    public function getDataFromXMLPage($url) {

		$xmlObj = FALSE;
		$ch = curl_init();
		 
		curl_setopt($ch, CURLOPT_URL, $url);
		curl_setopt($ch, CURLOPT_PORT, 80);
		if ($this->proxy && $this->proxyPort) {
			curl_setopt($ch, CURLOPT_PROXY, $this->proxy);
			curl_setopt($ch, CURLOPT_PROXYPORT, $this->proxyPort);
		}
		curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
		curl_setopt($ch, CURLOPT_TIMEOUT, 10);

		$result = curl_exec($ch);
		
		//curl_exec with CURLOPT_RETURNTRANSFER set 1 returns FALSE on error or
		//the result on success, so check for result.
		if ($result) {
		    
		    //simplexml_load_string will produce E_WARNING error messages for each error 
            //found in the XML data. Therefore suppress error messages in any mode and
            //handle errors for debug-mode differently.
            libxml_use_internal_errors(true);
            
            //parse the XML data.
            $xmlObj = simplexml_load_string($result);
            
            //log url to devlog in debug-mode if XML data contained errors.
            if ($this->debug) {
                $error_array = libxml_get_errors();
                if (count($error_array) > 0) {
                    t3lib_div::devLog('XML data contained errors: '.$url, 'libconnect', 1);
                }
            }
            
            //reset libxml error buffering and clear any existing libxml errors
            libxml_use_internal_errors(false);
            
		}
		
		//Pruefung ob Abfrage fehlerfrei erfolgte
		$http_code = curl_getinfo($ch);
		curl_close($ch);//Session schliessen
		
		if($http_code['http_code']!=200){
			$xmlObj = FALSE;
			
			if ($this->debug) t3lib_div::devLog('Got HTTP Code ' . $http_code['http_code'] . ' for request: ' . $url, 'libconnect', 1);
			
			return $xmlObj;
		}
		
		/* HINWEIS FEHLERPRUEFUNG: 
		 * Die Funktion curl_error() wie auch curl_getinfo() haben keine brauchbaren Rückgabewerte
		 * zurückgegeben. Deswegen die Pruefung ob ein Object erzeugt wurde und es ein
		 * SimpleXMLElement ist. 
		 */
		if ($xmlObj != FALSE) { //get_class produces E_WARNING for non-object arguments
		    if (!is_object($xmlObj) && get_class($xmlObj) == 'SimpleXMLElement' ) {
                $xmlObj = FALSE;
            }
		}
		
		return $xmlObj;
    }
}
?>